Documentation
¶
Overview ¶
Package io provides type definitions for use with the Chrome IO protocol
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CloseParams ¶
type CloseParams struct {
// Handle of the stream to close.
Handle StreamHandle `json:"handle"`
}
CloseParams represents IO.close parameters.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-close
type CloseResult ¶
type CloseResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
CloseResult represents the result of calls to IO.close.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-close
type ReadParams ¶
type ReadParams struct {
// Handle of the stream to read.
Handle StreamHandle `json:"handle"`
// Optional. Seek to the specified offset before reading (if not specificed,
// proceed with offset following the last read).
Offset int `json:"offset,omitempty"`
// Optional. Maximum number of bytes to read (left upon the agent discretion
// if not specified).
Size int `json:"size,omitempty"`
}
ReadParams represents IO.read parameters.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-read
type ReadResult ¶
type ReadResult struct {
// Set if the data is base64-encoded.
Base64Encoded bool `json:"base64Encoded"`
// Data that were read.
Data string `json:"data"`
// Set if the end-of-file condition occurred while reading.
EOF bool `json:"eof"`
// Error information related to executing this method
Err error `json:"-"`
}
ReadResult represents the result of calls to IO.read.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-read
type ResolveBlobParams ¶
type ResolveBlobParams struct {
// Object ID of a Blob object wrapper.
ObjectID runtime.RemoteObjectID `json:"objectId"`
}
ResolveBlobParams represents IO.resolveBlob parameters.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-resolveBlob
type ResolveBlobResult ¶
type ResolveBlobResult struct {
// UUID of the specified Blob.
UUID string `json:"uuid"`
// Error information related to executing this method
Err error `json:"-"`
}
ResolveBlobResult represents the result of calls to IO.resolveBlob.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#method-resolveBlob
type StreamHandle ¶
type StreamHandle string
StreamHandle is either obtained from another method or specified as blob:<uuid> where <uuid> is an UUID of a Blob.
https://chromedevtools.github.io/devtools-protocol/tot/IO/#type-StreamHandle